@@ -3,30 +3,30 @@
 %%% Author  : Alexey Shchepin <alexey@sevcom.net>
 %%% Purpose : 
 %%% Created : 18 Jan 2003 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id      : $Id: mod_time.erl 186 2003-12-17 20:13:21Z aleksey $
+%%% Id      : $Id: mod_time.erl 370 2005-06-20 03:18:13Z alexey $
 %%%----------------------------------------------------------------------
 
 -module(mod_time).
 -author('alexey@sevcom.net').
--vsn('$Revision$ ').
+-vsn('$Revision: 370 $ ').
 
 -behaviour(gen_mod).
 
--export([start/1,
-	 stop/0,
+-export([start/2,
+	 stop/1,
 	 process_local_iq/3]).
 
 -include("ejabberd.hrl").
 -include("jlib.hrl").
 
 
-start(Opts) ->
+start(Host, Opts) ->
     IQDisc = gen_mod:get_opt(iqdisc, Opts, one_queue),
-    gen_iq_handler:add_iq_handler(ejabberd_local, ?NS_TIME,
+    gen_iq_handler:add_iq_handler(ejabberd_local, Host, ?NS_TIME,
 				  ?MODULE, process_local_iq, IQDisc).
 
-stop() ->
-    gen_iq_handler:remove_iq_handler(ejabberd_local, ?NS_TIME).
+stop(Host) ->
+    gen_iq_handler:remove_iq_handler(ejabberd_local, Host, ?NS_TIME).
 
 process_local_iq(_From, _To, #iq{type = Type, sub_el = SubEl} = IQ) ->
     case Type of
